# Raspberry Pi LoRa KISS TNC

This project adds LoRa APRS to the Raspberry Pi. It is fully integrated in the Linux AX.25 stack for maximum flexibility.

This project was originally started by Tom Kottek (https://github.com/tomelec/RPi-LoRa-KISS-TNC). Because the program had some problems dealing with digipeated frames (it crashed when receiving a ssid with the 'has_been_digipeated' flag -*- set), I took on the task of fixing the code for my personal use.

The software is stable and can handle repeated frames (incomming and outgoing) so it can be used with the aprx software to make a digipeater.

## Software

The software controls the LoRa transceiver connected to the Raspberry´s SPI bus and emulates a KISS TNC over TCP. That makes it possible to use existing software like APRX. It is also possible to attach the KISS interface to the AX.25 stack via socat/kissattach.

Assuming you installed and configured the AX.25 stack, start the LoRa KISS TNC with these commands:

    #!/bin/bash

    # Start TNC software
    /usr/bin/python3 ~/RPi-LoRa-KISS-TNC/Start_lora-tnc.py &
    sleep 10
    # Attach TCP socket to virtual tty device located at /tmp/lorakisstnc
    sudo /usr/bin/socat PTY,raw,echo=0,link=/tmp/lorakisstnc TCP4:127.0.0.1:10001 &
    sleep 3
    # Attach virtual tty to AX.25 stack (port ax2)
    sudo /usr/sbin/kissattach /tmp/lorakisstnc ax2 &

## Hardware

[![How to connect LoRa module to Raspberry Pi](./images/RPi_LoRa_shield.svg)](./images/RPi_LoRa_shield.svg)

I also designed my own (open source) hardware for it: a board holding a Raspberry Pi Zero 2 W, an SX1278 LoRa transceiver and a power supply with on/off button to safely switch on and off the system. The design files can be found on my website: [RPi LoRa_shield](https://meezenest.nl/mees/RPi_LoRa_shield.html)

### To Do

* Add raw TCP KISS socket for true AX.25 over KISS
